@@ -56,11 +56,15 @@ class ClsHead(BaseHead):
         return losses
 
     def forward_train(self, cls_score, gt_label):
+        if isinstance(cls_score, tuple):
+            cls_score = cls_score[-1]
         losses = self.loss(cls_score, gt_label)
         return losses
 
     def simple_test(self, cls_score):
         """Test without augmentation."""
+        if isinstance(cls_score, tuple):
+            cls_score = cls_score[-1]
         if isinstance(cls_score, list):
             cls_score = sum(cls_score) / float(len(cls_score))
         pred = F.softmax(cls_score, dim=1) if cls_score is not None else None
