@@ -41,14 +41,18 @@ class MultiLabelClsHead(BaseHead):
         return losses
 
     def forward_train(self, cls_score, gt_label):
+        if isinstance(cls_score, tuple):
+            cls_score = cls_score[-1]
         gt_label = gt_label.type_as(cls_score)
         losses = self.loss(cls_score, gt_label)
         return losses
 
-    def simple_test(self, cls_score):
-        if isinstance(cls_score, list):
-            cls_score = sum(cls_score) / float(len(cls_score))
-        pred = F.sigmoid(cls_score) if cls_score is not None else None
+    def simple_test(self, x):
+        if isinstance(x, tuple):
+            x = x[-1]
+        if isinstance(x, list):
+            x = sum(x) / float(len(x))
+        pred = F.sigmoid(x) if x is not None else None
 
         return self.post_process(pred)
 
